Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/vax/uba iodone() -> biodone(), iowait() -> biowait()



details:   https://anonhg.NetBSD.org/src/rev/f644ec0fe34a
branches:  trunk
changeset: 480721:f644ec0fe34a
user:      thorpej <thorpej%NetBSD.org@localhost>
date:      Tue Jan 18 19:51:03 2000 +0000

description:
iodone() -> biodone(), iowait() -> biowait()

diffstat:

 sys/arch/vax/uba/ts.c |  20 ++++++++++----------
 1 files changed, 10 insertions(+), 10 deletions(-)

diffs (65 lines):

diff -r a6b37f161515 -r f644ec0fe34a sys/arch/vax/uba/ts.c
--- a/sys/arch/vax/uba/ts.c     Tue Jan 18 19:50:32 2000 +0000
+++ b/sys/arch/vax/uba/ts.c     Tue Jan 18 19:51:03 2000 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ts.c,v 1.14 2000/01/17 04:55:28 matt Exp $ */
+/*     $NetBSD: ts.c,v 1.15 2000/01/18 19:51:03 thorpej Exp $ */
 
 /*-
  * Copyright (c) 1991 The Regents of the University of California.
@@ -402,11 +402,11 @@
         * This is the only case where count can be 0.
         */
        if (count == 0) {
-               debug (("tscommand: direct return, no iowait.\n"));
+               debug (("tscommand: direct return, no biowait.\n"));
                return;
        }
-       debug (("tscommand: calling iowait ...\n"));;
-       iowait (bp);
+       debug (("tscommand: calling biowait ...\n"));;
+       biowait (bp);
        if (bp->b_flags & B_WANTED)
                wakeup ((caddr_t)bp);
        bp->b_flags &= B_ERROR;
@@ -438,7 +438,7 @@
                /* bertram: ubarelse ??? */
                ts_wtab[ctlr] = NULL;
                dp->b_flags |= B_ERROR;
-               iodone (dp);
+               biodone (dp);
 
                if (tsreg->tssr & TS_SC) {      /* Special Condition; Error */
                        log (TS_PRI, "%s: tssr 0x%x, state %d\n",
@@ -566,7 +566,7 @@
                /*
                 * we are already waiting for something ...
                 * this should not happen, so we have a problem now.
                 * bertram: set error-flag and call iodone() ???
                 */
        }
        ts_wtab[ctlr] = bp;
@@ -930,9 +930,9 @@
 #endif
                        }
                        bp->b_resid = tsmsgp->rbpcr;
-                       debug (("tsintr: iodone(NORM) [%d,%d,%d]\n",
+                       debug (("tsintr: biodone(NORM) [%d,%d,%d]\n",
                                bp->b_resid, bp->b_bcount, tsmsgp->rbpcr));
-                       iodone (bp); /* bertram: ioctl ??? */
+                       biodone (bp); /* bertram: ioctl ??? */
                }
                return;
 
@@ -1080,8 +1080,8 @@
                debug (("resid:%d, count:%d, rbpcr:%d\n",
                        bp->b_resid, bp->b_bcount, tsmsgp->rbpcr));
                bp->b_resid = tsmsgp->rbpcr; /* XXX */
-               debug (("tsintr: iodone(%x)\n", bp->b_flags));
-               iodone (bp);
+               debug (("tsintr: biodone(%x)\n", bp->b_flags));
+               biodone (bp);
        }
        if ((sr & TS_TC) > TS_TC_FR)
                tsreset (ctlr);
@@ -566,7 +566,7 @@
                 * we are already waiting for something ...
                 * this should not happen, so we have a problem now.
-                * bertram: set error-flag and call iodone() ???
+                * bertram: set error-flag and call biodone() ???
                 */
        }



Home | Main Index | Thread Index | Old Index